==> meedu_player-0.0.3.tar.gz: example/lib/pages/network_with_subtitle_page.dart <==
import 'package:flutter/material.dart';
import 'package:meedu_player/meedu_player.dart';

class NetworkWithSubtitlesPage extends StatefulWidget {
  @override
  _NetworkWithSubtitlesPageState createState() =>
      _NetworkWithSubtitlesPageState();
}

class _NetworkWithSubtitlesPageState extends State<NetworkWithSubtitlesPage> {
  MeeduPlayerController _controller = MeeduPlayerController(
    backgroundColor: Colors.black,
  );

  ValueNotifier<bool> _subtitlesEnabled = ValueNotifier(true);

  @override
  void initState() {
    super.initState();
    this._setDataSource();
  }

  @override
  void dispose() {
    this._controller.dispose();
    super.dispose();
  }

  _setDataSource() {
    _controller.setDataSource(
      autoPlay: true,
      header: Container(
        padding: EdgeInsets.all(10),
        child: Text(
          "Subtitles Demo",
          style: TextStyle(
            color: Colors.white,
          ),
        ),
      ),
      dataSource: DataSource(
        dataSource:
            'https://thepaciellogroup.github.io/AT-browser-tests/video/ElephantsDream.mp4',
        type: DataSourceType.network,
        closedCaptionFile: this._loadCaptions(),
      ),
      bottomLeftContent: FlatButton(
        child: ValueListenableBuilder(
          valueListenable: this._subtitlesEnabled,
          builder: (BuildContext context, bool enabled, Widget child) {
            return Text(
              "CC",
              style: TextStyle(
                color: Colors.white.withOpacity(
                  enabled ? 1 : 0.4,
                ),
              ),
            );
          },
        ),
        onPressed: () {
          _subtitlesEnabled.value = !_subtitlesEnabled.value;
          this._controller.isClosedCaptionEnabled(_subtitlesEnabled.value);
        },
      ),
    );
  }

  Future<ClosedCaptionFile> _loadCaptions() async {
    // you can get the fileContents as string from a remote str file using a http client like dio or http
    // or you can load from assets
    /*
    final String fileContents = await DefaultAssetBundle.of(context)
        .loadString('assets/captions.srt');
    */
    // in srt format
    final String fileContents = '''
0
00:00:02,170 --> 00:00:04,136
Emo, close your eyes

1
00:00:04,136 --> 00:00:05,597
Why?
NOW!

2
00:00:05,597 --> 00:00:07,405
Ok

3
00:00:07,405 --> 00:00:08,803
Good

4
00:00:08,803 --> 00:00:11,541
What do you see at your left side Emo?

5
00:00:11,541 --> 00:00:13,287
Well?

6
00:00:13,287 --> 00:00:16,110
Er nothing?
Really?

7
00:00:16,110 --> 00:00:18,514
No, nothing at all!

8
00:00:18,514 --> 00:00:22,669
Really? and at your right? What do you see at your right side Emo?

9
00:00:22,669 --> 00:00:26,111
Umm, the same Proog

10
00:00:26,111 --> 00:00:28,646
Exactly the same! Nothing!

11
00:00:28,646 --> 00:00:30,794
Great
    ''';
    return SubRipCaptionFile(fileContents);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
      body: SafeArea(
        child: MeeduPlayer(
          controller: this._controller,
        ),
      ),
    );
  }
}

==> meedu_player-0.2.2.tar.gz: example/lib/pages/network_with_subtitle_page.dart <==
import 'package:flutter/material.dart';
import 'package:meedu_player/meedu_player.dart';

class NetworkWithSubtitlesPage extends StatefulWidget {
  @override
  _NetworkWithSubtitlesPageState createState() =>
      _NetworkWithSubtitlesPageState();
}

class _NetworkWithSubtitlesPageState extends State<NetworkWithSubtitlesPage> {
  MeeduPlayerController _controller = MeeduPlayerController(
    backgroundColor: Colors.black,
  );

  ValueNotifier<bool> _subtitlesEnabled = ValueNotifier(true);

  Widget get ccButton {
    return FlatButton(
      child: ValueListenableBuilder(
        valueListenable: this._subtitlesEnabled,
        builder: (BuildContext context, bool enabled, Widget child) {
          return Text(
            "CC",
            style: TextStyle(
              color: Colors.white.withOpacity(
                enabled ? 1 : 0.4,
              ),
            ),
          );
        },
      ),
      onPressed: () {
        _subtitlesEnabled.value = !_subtitlesEnabled.value;
        this._controller.isClosedCaptionEnabled(_subtitlesEnabled.value);
      },
    );
  }

  @override
  void initState() {
    super.initState();
    this._setDataSource();
  }

  @override
  void dispose() {
    this._controller.dispose();
    super.dispose();
  }

  _setDataSource() {
    _controller.setDataSource(
      autoPlay: true,
      header: Container(
        padding: EdgeInsets.all(10),
        child: Text(
          "Subtitles Demo",
          style: TextStyle(
            color: Colors.white,
          ),
        ),
      ),
      dataSource: DataSource(
        dataSource:
            'https://thepaciellogroup.github.io/AT-browser-tests/video/ElephantsDream.mp4',
        type: DataSourceType.network,
        closedCaptionFile: this._loadCaptions(),
      ),
      bottomLeftContent: ccButton,
    );
  }

  Future<ClosedCaptionFile> _loadCaptions() async {
    // you can get the fileContents as string from a remote str file using a http client like dio or http
    // or you can load from assets
    /*
    final String fileContents = await DefaultAssetBundle.of(context)
        .loadString('assets/captions.srt');
    */
    // in srt format
    final String fileContents = '''
0
00:00:02,170 --> 00:00:04,136
Emo, close your eyes

1
00:00:04,136 --> 00:00:05,597
Why?
NOW!

2
00:00:05,597 --> 00:00:07,405
Ok

3
00:00:07,405 --> 00:00:08,803
Good

4
00:00:08,803 --> 00:00:11,541
What do you see at your left side Emo?

5
00:00:11,541 --> 00:00:13,287
Well?

6
00:00:13,287 --> 00:00:16,110
Er nothing?
Really?

7
00:00:16,110 --> 00:00:18,514
No, nothing at all!

8
00:00:18,514 --> 00:00:22,669
Really? and at your right? What do you see at your right side Emo?

9
00:00:22,669 --> 00:00:26,111
Umm, the same Proog

10
00:00:26,111 --> 00:00:28,646
Exactly the same! Nothing!

11
00:00:28,646 --> 00:00:30,794
Great
    ''';
    return SubRipCaptionFile(fileContents);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
      body: SafeArea(
        child: MeeduPlayer(
          controller: this._controller,
        ),
      ),
    );
  }
}
